@@ -4,7 +4,7 @@ from yamlpath.exceptions import YAMLPathException
 from yamlpath.enums import PathSegmentTypes, PathSeperators
 from yamlpath import YAMLPath
 
-class Test_path_Path():
+class Test_YAMLPath():
     """Tests for the Path class."""
 
     @pytest.mark.parametrize("yamlpath,pathsep,output", [
@@ -32,8 +32,8 @@ class Test_path_Path():
         ("a*f", PathSeperators.AUTO, "[.=~/^a.*f$/]"),
         ("a*f*z", PathSeperators.AUTO, "[.=~/^a.*f.*z$/]"),
         ("a*f*z*", PathSeperators.AUTO, "[.=~/^a.*f.*z.*$/]"),
-        ("*", PathSeperators.AUTO, "[.=~/.*/]"),
-        ("*.*", PathSeperators.AUTO, "[.=~/.*/][.=~/.*/]"),
+        ("*", PathSeperators.AUTO, "*"),
+        ("*.*", PathSeperators.AUTO, "*.*"),
         ("**", PathSeperators.AUTO, "**"),
         ("/**/def", PathSeperators.AUTO, "/**/def"),
         ("abc.**.def", PathSeperators.AUTO, "abc.**.def"),
@@ -186,3 +186,35 @@ class Test_path_Path():
         with pytest.raises(YAMLPathException) as ex:
             str(YAMLPath("abc**"))
         assert -1 < str(ex.value).find("The ** traversal operator has no meaning when combined with other characters")
+
+    def test_parse_bad_following_char(self):
+        with pytest.raises(YAMLPathException) as ex:
+            str(YAMLPath("abc[has_child(def)ghi]"))
+        assert -1 < str(ex.value).find("Invalid YAML Path at g, which must be ]")
+
+    def test_parse_unknown_search_keyword(self):
+        with pytest.raises(YAMLPathException) as ex:
+            str(YAMLPath("abc[unknown_keyword()]"))
+        assert -1 < str(ex.value).find("Unknown search keyword, unknown_keyword")
+
+    @pytest.mark.parametrize("path,pops,results", [
+        ("/abc", 1, [(PathSegmentTypes.KEY, "abc")]),
+        ("abc", 1, [(PathSegmentTypes.KEY, "abc")]),
+        ("/abc/def", 2, [(PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+        ("abc.def", 2, [(PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+        ("/abc/def[3]", 3, [(PathSegmentTypes.INDEX, 3), (PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+        ("abc.def[3]", 3, [(PathSegmentTypes.INDEX, 3), (PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+        ("/abc/def[3][1]", 4, [(PathSegmentTypes.INDEX, 1), (PathSegmentTypes.INDEX, 3), (PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+        ("abc.def[3][1]", 4, [(PathSegmentTypes.INDEX, 1), (PathSegmentTypes.INDEX, 3), (PathSegmentTypes.KEY, "def"), (PathSegmentTypes.KEY, "abc")]),
+    ])
+    def test_pop_segments(self, path, pops, results):
+        yp = YAMLPath(path)
+        for pop in range(pops):
+            assert results[pop] == yp.pop()
+
+    def test_pop_too_many(self):
+        yp = YAMLPath("abc.def")
+        with pytest.raises(YAMLPathException) as ex:
+            for _ in range(5):
+                yp.pop()
+        assert -1 < str(ex.value).find("Cannot pop when")
